===============================================================
qirest-client: Quantitative Imaging Profile REST client
===============================================================

Displays the OHSU QIN images and annotations. See the
`documentation <http://qiprofile-rest-client.readthedocs.org/en/latest/>`_
for more information.
